@@ -5,8 +5,7 @@
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef TESTFREEPERIODMODEL_H
-#define TESTFREEPERIODMODEL_H
+#pragma once
 
 #include <QObject>
 
@@ -20,4 +19,3 @@ private Q_SLOTS:
     void testSplitByDay();
 };
 }
-#endif
